@@ -6,9 +6,9 @@ use bevy::prelude::*;
 use notation_bevy_utils::prelude::{
     BevyUtil, GridCell, LayoutAnchor, LayoutChangedWithChildrenQuery, View, ViewBundle,
 };
-use notation_model::prelude::{Chord, ModelEntry, Position, Tab, TabBar};
+use notation_model::prelude::{TabChord};
 
-use crate::prelude::NotationTheme;
+use crate::prelude::{NotationTheme, NotationAssets};
 use crate::ui::layout::NotationLayout;
 
 use super::chord_base::ChordBaseData;
@@ -17,9 +17,9 @@ use super::chord_interval::ChordIntervalData;
 use super::chord_playing::ChordPlaying;
 use super::interval_dot::IntervalDotData;
 
+#[derive(Clone, Debug)]
 pub struct ChordView {
-    pub entry: Arc<ModelEntry>,
-    pub chord: Chord,
+    pub chord: TabChord,
 }
 
 impl Display for ChordView {
@@ -28,46 +28,6 @@ impl Display for ChordView {
     }
 }
 
-impl ChordView {
-    pub fn search_in_bars(
-        &self,
-        tab: &Arc<Tab>,
-        begin_bar_ordinal: usize,
-        end_bar_ordinal: usize,
-    ) -> Option<Arc<TabBar>> {
-        for bar_ordinal in begin_bar_ordinal..=end_bar_ordinal {
-            if let Some(bar) = tab.get_bar_of_ordinal(bar_ordinal) {
-                let chords = bar.get_chords();
-                if chords.contains(&self.chord) {
-                    return Some(bar);
-                }
-            }
-        }
-        None
-    }
-    pub fn search_next(&self, pass_end: bool, position: Option<Position>) -> Option<Arc<TabBar>> {
-        if let Some(tab) = self.entry.tab() {
-            let last_bar_ordinal = tab.bars.len() + 1;
-            match position {
-                Some(pos) => {
-                    let bar_ordinal = pos.bar.bar_ordinal;
-                    if let Some(entry) =
-                        self.search_in_bars(&tab, bar_ordinal + 1, last_bar_ordinal)
-                    {
-                        return Some(entry);
-                    } else if pass_end {
-                        return self.search_in_bars(&tab, 1, bar_ordinal);
-                    }
-                }
-                None => {
-                    return self.search_in_bars(&tab, 1, last_bar_ordinal);
-                }
-            }
-        }
-        None
-    }
-}
-
 impl<'a> View<NotationLayout<'a>> for ChordView {
     fn pivot(&self) -> LayoutAnchor {
         LayoutAnchor::CENTER
@@ -84,7 +44,9 @@ impl ChordView {
         mut interval_query: Query<(Entity, &mut ChordIntervalData, &Children)>,
         mut base_query: Query<(Entity, &mut ChordBaseData, &Children)>,
         mut dot_query: Query<(Entity, &mut IntervalDotData)>,
+        mut text_query: Query<&mut Transform, With<Text>>,
     ) {
+        if theme._bypass_systems { return; }
         for (_entity, _view, layout, children) in query.iter() {
             let radius = layout.size.width * theme.sizes.chord.diagram_factor;
             for child in children.iter() {
@@ -102,30 +64,38 @@ impl ChordView {
                         radius,
                     );
                 }
+                if let Ok(mut transform) = text_query.get_mut(*child) {
+                    theme.texts.chord.update_bars_xy(&mut transform, layout);
+                }
             }
         }
     }
     pub fn spawn(
         commands: &mut Commands,
+        assets: &NotationAssets,
         theme: &NotationTheme,
         entity: Entity,
-        chord: Chord,
-        entry: &Arc<ModelEntry>,
+        chord: &TabChord,
     ) -> Entity {
         let chord_entity = BevyUtil::spawn_child_bundle(
             commands,
             entity,
-            ViewBundle::from(ChordView {
-                entry: entry.clone(),
-                chord,
-            }),
+            ViewBundle::from(ChordView{chord: chord.clone()}),
         );
         //TODO: handle initialization in a nicer way.
         let radius = 0.0;
-        ChordDiagramData::spawn(commands, theme, chord_entity, entry.props, chord, radius);
+        ChordDiagramData::spawn(commands, theme, chord_entity, chord.first_entry().unwrap().props, chord.chord, radius);
         commands
             .entity(chord_entity)
-            .insert(ChordPlaying::from((entry.props, chord)));
+            .insert(ChordPlaying::from((chord.first_entry().unwrap().props, chord.chord)));
+        if chord.bars.len() > 1 {
+            theme.texts.chord.spawn_bars_text(
+                commands,
+                assets,
+                chord_entity,
+                chord.bars.len().to_string().as_str(),
+            );
+        }
         chord_entity
     }
     pub fn on_chord_playing_changed(
@@ -137,6 +107,7 @@ impl ChordView {
         >,
         mut diagram_query: Query<(Entity, &mut ChordDiagramData)>,
     ) {
+        if theme._bypass_systems { return; }
         for (_entity, playing, _view, children) in query.iter_mut() {
             for child in children.iter() {
                 if let Ok((diagram_entity, mut diagram_data)) = diagram_query.get_mut(*child) {
