@@ -30,7 +30,7 @@ impl MiniMap {
     pub fn calc_grid_data(&self, engine: &NotationLayout, grid_size: LayoutSize) -> GridData {
         let sizes = engine.theme.sizes.mini_map;
         let (rows, cols, cell_width) = GridData::cals_fixed_rows_cols_by_width(
-            grid_size.width,
+            grid_size.width - sizes.bar_margin.1 * 2.0,
             sizes.bar_width_range,
             sizes.bar_margin().width,
             self.tab.bars.len(),
@@ -75,15 +75,17 @@ impl MiniMap {
     ) -> Entity {
         let minimap = MiniMap::new(tab.clone());
         let map_entity = BevyUtil::spawn_child_bundle(commands, entity, ViewBundle::from(minimap));
-        ColorBackground::spawn(
+        let background_entity = ColorBackground::spawn(
             commands,
             map_entity,
-            theme.core.mini_map_z,
+            theme.z.mini_map,
             theme.colors.mini_map.back,
         );
         for bar in tab.bars.iter() {
             MiniBar::spawn(commands, assets, theme, map_entity, bar);
         }
+        theme.texts.mini_map
+            .spawn_debug_text(commands, background_entity, &assets, "");
         map_entity
     }
     pub fn do_layout(
@@ -107,4 +109,20 @@ impl MiniMap {
             )
         }
     }
+    pub fn update_debug_str(
+        app_state: Res<NotationAppState>,
+        background_query: Query<&ColorBackground>,
+        mut font_query: Query<(&Parent, &mut Text)>,
+    ) {
+        for (parent, mut text) in font_query.iter_mut() {
+            if let Ok(_) = background_query.get(parent.0) {
+                let str = if let Some(debug_str) = &app_state.debug_str {
+                    debug_str.to_string()
+                } else {
+                    "".to_string()
+                };
+                BevyUtil::set_text_value(&mut text, str);
+            }
+        }
+    }
 }
