@@ -18,6 +18,7 @@ pub fn on_entry_playing_changed(
     )>,
     mut font_query: Query<&mut Text>,
 ) {
+    if theme._bypass_systems { return; }
     for (_entity, playing, children) in query.iter() {
         for child in children.iter() {
             if let Ok((entity, mut data, note_children)) = note_query.q0_mut().get_mut(*child) {
@@ -65,7 +66,7 @@ macro_rules! impl_pick_system {
                             let note_entity = data.create(commands, theme, entity);
                             if settings.always_show_fret || pick_note.fret.is_some() {
                                 theme
-                                    .strings
+                                    .texts.strings
                                     .spawn_fret_text(commands, note_entity, &assets, fret);
                             }
                         }
