@@ -47,11 +47,15 @@ impl<'a> GridView<NotationLayout<'a>, BarView> for TabBars {
             return GridData::ZERO;
         }
         let bar_margin = engine.theme.sizes.layout.bar_margin;
-        let bar_sizes = engine.theme.sizes.bar;
+        let beat_size_range =
+            match engine.settings.override_beat_size {
+                Some(size) => (size, size * 2.0),
+                None => engine.theme.sizes.bar.beat_size_range,
+            };
         let bar_beats = self.tab.bar_beats() as f32;
         let bar_width_range = (
-            bar_sizes.beat_size_range.0 * bar_beats,
-            bar_sizes.beat_size_range.1 * bar_beats,
+            beat_size_range.0 * bar_beats,
+            beat_size_range.1 * bar_beats,
         );
         let (rows, cols, cell_width) = GridData::cals_fixed_rows_cols_by_width(
             grid_size.width - bar_margin * 2.0,
@@ -132,7 +136,7 @@ impl TabBars {
             for lane in bar.lanes.iter() {
                 let lane_id = lane.id();
                 if !lane_layouts.contains_key(&lane_id) {
-                    let height = theme.sizes.layout.calc_lane_height(lane.kind);
+                    let height = theme.sizes.calc_lane_height(lane.kind);
                     let margin = theme.sizes.layout.lane_margin;
                     lane_layouts.insert(lane_id, LaneLayoutData::new(&lane, height, margin));
                 }
@@ -183,7 +187,7 @@ impl TabBars {
         let view_bundle = ViewBundle::from(TabBars::new(tab.clone(), Arc::new(bar_layouts)));
         let view = view_bundle.view.clone();
         let bars_entity = BevyUtil::spawn_child_bundle(commands, entity, view_bundle);
-        PlayPlugin::spawn_indicators(commands, theme, bars_entity, &view.tab);
+        PlayPlugin::spawn_indicators(commands, theme, bars_entity, tab);
         let bar_bundles: Vec<(&Arc<TabBar>, &BarLayoutData)> = view
             .tab
             .bars
@@ -211,9 +215,11 @@ impl TabBars {
     }
     pub fn on_resized_pre(
         mut evts: EventReader<TabBarsResizedPreEvent>,
+        theme: Res<NotationTheme>,
         cell_query: Query<(&Parent, &Arc<BarView>, &LayoutData)>,
         mut tab_resized_evts: EventWriter<TabBarsResizedEvent>,
     ) {
+        if theme._bypass_systems { return; }
         for evt in evts.iter() {
             let mut bars = Vec::new();
             for (parent, bar_view, layout) in cell_query.iter() {
@@ -234,6 +240,7 @@ impl TabBars {
         cell_query: ViewQuery<BarView>,
         mut tab_resized_evts: EventWriter<TabBarsResizedPreEvent>,
     ) {
+        if theme._bypass_systems { return; }
         let engine = NotationLayout::new(&theme, &state, &settings);
         for evt in evts.iter() {
             evt.view.do_layout(
