@@ -4,28 +4,28 @@ use std::sync::Arc;
 use bevy::prelude::*;
 
 use notation_bevy_utils::prelude::{
-    BevyUtil, ColorBackground, GridData, GridView, LayoutAnchor, LayoutChangedQuery,
+    BevyUtil, GridData, GridView, LayoutAnchor, LayoutChangedQuery,
     LayoutConstraint, LayoutQuery, LayoutSize, View, ViewBundle, ViewQuery,
 };
-use notation_model::prelude::{Chord, ModelEntry, Tab};
+use notation_model::prelude::{Tab, TabChord};
 
 use crate::chord::chord_view::ChordView;
-use crate::prelude::{NotationAppState, NotationSettings, NotationTheme};
+use crate::prelude::{NotationAppState, NotationSettings, NotationTheme, NotationAssets};
 use crate::ui::layout::NotationLayout;
 
 use super::tab_events::TabChordsDoLayoutEvent;
 
 pub struct TabChords {
     pub tab: Arc<Tab>,
-    pub chords: Vec<(Chord, Arc<ModelEntry>)>,
+    pub chords: Vec<TabChord>,
 }
 impl Display for TabChords {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "<TabChords>({})", self.tab.bars.len())
+        write!(f, "<TabChords>(B:{}, C:{})", self.tab.bars.len(), self.chords.len())
     }
 }
 impl TabChords {
-    pub fn new(tab: Arc<Tab>, chords: Vec<(Chord, Arc<ModelEntry>)>) -> Self {
+    pub fn new(tab: Arc<Tab>, chords: Vec<TabChord>) -> Self {
         Self { tab, chords }
     }
     pub fn calc_grid_data<'a>(
@@ -33,10 +33,14 @@ impl TabChords {
         grid_size: LayoutSize,
         chords: usize,
     ) -> GridData {
-        let sizes = engine.theme.sizes.chord;
+        let chord_size_range =
+            match engine.settings.override_chord_size {
+                Some(size) => (size, size),
+                None => engine.theme.sizes.chord.chord_size_range,
+            };
         let (mut rows, mut cols, cell_width) = GridData::cals_fixed_rows_cols_by_width(
             grid_size.width,
-            sizes.chord_size_range,
+            chord_size_range,
             0.0,
             chords,
         );
@@ -74,22 +78,17 @@ impl<'a> View<NotationLayout<'a>> for TabChords {
 impl TabChords {
     pub fn spawn(
         commands: &mut Commands,
+        assets: &NotationAssets,
         theme: &NotationTheme,
         entity: Entity,
         tab: &Arc<Tab>,
-        chords: &Vec<(Chord, Arc<ModelEntry>)>,
+        chords: &Vec<TabChord>,
     ) -> Entity {
         let view_bundle = ViewBundle::from(TabChords::new(tab.clone(), chords.clone()));
         let view = view_bundle.view.clone();
         let chords_entity = BevyUtil::spawn_child_bundle(commands, entity, view_bundle);
-        ColorBackground::spawn(
-            commands,
-            chords_entity,
-            theme.core.mini_map_z,
-            theme.colors.chord.background,
-        );
-        for (chord, entry) in view.chords.iter() {
-            ChordView::spawn(commands, theme, chords_entity, *chord, entry);
+        for chord_view in view.chords.iter() {
+            ChordView::spawn(commands, assets, theme, chords_entity, chord_view);
         }
         chords_entity
     }
@@ -102,6 +101,7 @@ impl TabChords {
         mut layout_query: LayoutQuery,
         cell_query: ViewQuery<ChordView>,
     ) {
+        if theme._bypass_systems { return; }
         let engine = NotationLayout::new(&theme, &state, &settings);
         for evt in evts.iter() {
             evt.view.do_layout(
