@@ -1,7 +1,7 @@
 use std::sync::Arc;
 
 use bevy::prelude::*;
-use notation_bevy_utils::prelude::{LayoutData};
+use notation_bevy_utils::prelude::{LayoutData, GridData};
 use notation_midi::prelude::{JumpToBarEvent, MidiState, PlayControlEvent};
 use notation_model::prelude::TabBarProps;
 
@@ -69,29 +69,30 @@ fn jump_to_bar(
 
 fn on_mouse_clicked(
     mut evts: EventReader<MouseClickedEvent>,
-    _theme: Res<NotationTheme>,
+    theme: Res<NotationTheme>,
     mut app_state: ResMut<NotationAppState>,
     mut settings: ResMut<NotationSettings>,
     tab_state_query: Query<(Entity, &TabState), With<TabState>>,
     mini_bar_query: Query<(&Arc<MiniBar>, &LayoutData, &GlobalTransform)>,
     button_query: Query<(&Arc<PlayButton>, &LayoutData, &GlobalTransform)>,
-    control_query: Query<(&Arc<TabControl>, &LayoutData, &GlobalTransform)>,
+    rhythm_query: Query<(&Arc<RhythmView>, &LayoutData, &GlobalTransform)>,
     chord_query: Query<(&Arc<ChordView>, &LayoutData, &GlobalTransform)>,
     bar_query: Query<(&Arc<BarView>, &LayoutData, &GlobalTransform)>,
     mut jump_to_bar_evts: EventWriter<JumpToBarEvent>,
     mut midi_state: ResMut<MidiState>,
     mut play_control_evts: EventWriter<PlayControlEvent>,
 ) {
+    if theme._bypass_systems { return; }
     let mut pos = None;
     for evt in evts.iter() {
         pos = Some(app_state.convert_pos(evt.cursor_position));
     }
     if let Some(pos) = pos {
         if !app_state.hide_control {
-            if app_state.window_width / 2.0 - pos.x > ControlView::WIDTH {
+            if app_state.window_width / 2.0 - pos.x > ControlView::calc_width(app_state.window_width) {
                 app_state.hide_control = true;
             }
-        } else if !settings.mouse_dragged_panning {
+        } else {
             println!("tab_plugin::on_mouse_clicked() -> {:?}", pos);
             for (mini_bar, layout, global_transform) in mini_bar_query.iter() {
                 if layout.is_pos_inside(pos, global_transform) {
@@ -120,7 +121,7 @@ fn on_mouse_clicked(
                     return;
                 }
             }
-            for (_control, layout, global_transform) in control_query.iter() {
+            for (_rhythm_view, layout, global_transform) in rhythm_query.iter() {
                 if layout.is_pos_inside(pos, global_transform) {
                     if app_state.hide_control {
                         app_state.hide_control = false;
@@ -131,8 +132,8 @@ fn on_mouse_clicked(
             for (chord, layout, global_transform) in chord_query.iter() {
                 if layout.is_pos_inside(pos, global_transform) {
                     let position =
-                        TabState::get_position(&tab_state_query, chord.entry.tab().map(|x| x.uuid));
-                    if let Some(next_bar) = chord.search_next(true, position) {
+                        TabState::get_position(&tab_state_query, chord.chord.tab().map(|x| x.uuid));
+                    if let Some(next_bar) = chord.chord.search_next(true, position) {
                         jump_to_bar(&mut jump_to_bar_evts, next_bar.props);
                     }
                     return;
@@ -150,14 +151,22 @@ fn on_mouse_clicked(
 
 fn on_mouse_dragged(
     mut evts: EventReader<MouseDraggedEvent>,
+    theme: Res<NotationTheme>,
     settings: Res<NotationSettings>,
-    mut tab_bars_query: Query<(Entity, &mut Transform, &Arc<TabBars>)>,
+    mut tab_bars_query: Query<(
+            Entity,
+            &mut Transform,
+            &Arc<TabBars>,
+            &LayoutData,
+            &Arc<GridData>,
+        )>,
 ) {
+    if theme._bypass_systems { return; }
     for evt in evts.iter() {
-        if settings.mouse_dragged_panning {
+        if settings.allow_panning {
             settings
                 .layout
-                .pan_tab_bars(&mut tab_bars_query, -evt.delta.x, -evt.delta.y);
+                .pan_tab_bars(&theme, &mut tab_bars_query, -evt.delta.x, -evt.delta.y);
         }
     }
 }
