@@ -52,8 +52,8 @@ impl ShapeOp<NotationTheme, OutlineRectangle> for ToneNoteData {
                 * self.entry_props.in_bar_pos.0;
             let y = if self.value.mode.is_melody() {
                 theme
-                    .melody
-                    .calc_note_y(self.value.note, self.value.syllable_note)
+                    .sizes.melody
+                    .calc_note_y(self.value.syllable_note)
             } else {
                 0.0
             };
@@ -63,7 +63,7 @@ impl ShapeOp<NotationTheme, OutlineRectangle> for ToneNoteData {
             } else {
                 0.0
             };
-            Vec3::new(x, y + height / 2.0, theme.strings.pick_z + extra_z)
+            Vec3::new(x, y + height / 2.0, theme.z.tone + extra_z)
         };
         OutlineRectangle {
             width,
@@ -89,10 +89,10 @@ impl ToneNoteData {
         let outline = self.calc_outline(theme);
         let width = self.value.bar_size / self.bar_props.bar_units.0
             * self.entry_props.tied_units.0;
-        let mut height = theme.melody.note_height;
+        let mut height = theme.sizes.melody.note_height;
         if self.value.playing_state.is_current() {
             height += outline;
         }
-        (width, height)
+        (width - outline * 2.0, height)
     }
 }
\ No newline at end of file
